@@ -15,7 +15,7 @@ impl MinFlt {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("MinorFaults"));
         let unit = String::new();
-        MinFlt {
+        Self {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
             width: 0,
@@ -38,7 +38,6 @@ impl Column for MinFlt {
     column_default!(u64);
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "macos")]
 impl Column for MinFlt {
     fn add(&mut self, proc: &ProcessInfo) {
@@ -52,3 +51,16 @@ impl Column for MinFlt {
 
     column_default!(u64);
 }
+
+#[cfg(target_os = "freebsd")]
+impl Column for MinFlt {
+    fn add(&mut self, proc: &ProcessInfo) {
+        let raw_content = proc.curr_proc.info.rusage.minflt as u64;
+        let fmt_content = format!("{raw_content}");
+
+        self.fmt_contents.insert(proc.pid, fmt_content);
+        self.raw_contents.insert(proc.pid, raw_content);
+    }
+
+    column_default!(u64);
+}
