@@ -15,7 +15,7 @@ impl SigCgt {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("SigCgt"));
         let unit = String::new();
-        SigCgt {
+        Self {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
             width: 0,
@@ -25,6 +25,7 @@ impl SigCgt {
     }
 }
 
+#[cfg(any(target_os = "linux", target_os = "android"))]
 impl Column for SigCgt {
     fn add(&mut self, proc: &ProcessInfo) {
         let (fmt_content, raw_content) = if let Some(ref status) = proc.curr_status {
@@ -40,3 +41,16 @@ impl Column for SigCgt {
 
     column_default!(u64);
 }
+
+#[cfg(target_os = "freebsd")]
+impl Column for SigCgt {
+    fn add(&mut self, proc: &ProcessInfo) {
+        let raw_content = proc.curr_proc.info.sigcatch.0[0] as u64;
+        let fmt_content = format!("{raw_content:016x}");
+
+        self.fmt_contents.insert(proc.pid, fmt_content);
+        self.raw_contents.insert(proc.pid, raw_content);
+    }
+
+    column_default!(u64);
+}
