@@ -15,7 +15,7 @@ impl SigIgn {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("SigIgn"));
         let unit = String::new();
-        SigIgn {
+        Self {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
             width: 0,
