@@ -19,7 +19,7 @@ impl UserLogin {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("Login User"));
         let unit = String::new();
-        UserLogin {
+        Self {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
             width: 0,
