@@ -2,11 +2,11 @@ use crate::column::Column;
 use crate::columns::{ConfigColumnKind, KIND_LIST};
 use crate::config::{Config, ConfigColumnAlign, ConfigSearchCase, ConfigSearchLogic, ConfigTheme};
 use crate::Opt;
-use byte_unit::Byte;
+use byte_unit::{Byte, UnitType};
 use clap::ValueEnum;
-use is_terminal::IsTerminal;
 use std::borrow::Cow;
 use std::io;
+use std::io::IsTerminal;
 use std::time::Duration;
 use std::time::Instant;
 use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
@@ -209,11 +209,7 @@ pub fn truncate(s: &'_ str, width: usize) -> Cow<'_, str> {
             buf.push(c);
             continue;
         }
-        total_width += if let Some(x) = UnicodeWidthChar::width(c) {
-            x
-        } else {
-            0
-        };
+        total_width += UnicodeWidthChar::width(c).unwrap_or_default();
         if total_width > width {
             ret = Some(buf);
             break;
@@ -244,7 +240,6 @@ pub fn find_column_kind(pat: &str) -> Option<ConfigColumnKind> {
     None
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "macos")]
 pub fn change_endian(val: u32) -> u32 {
     let mut ret = 0;
@@ -255,7 +250,6 @@ pub fn change_endian(val: u32) -> u32 {
     ret
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "macos")]
 pub unsafe fn get_sys_value(
     high: u32,
@@ -276,7 +270,6 @@ pub unsafe fn get_sys_value(
     ) == 0
 }
 
-#[cfg_attr(tarpaulin, skip)]
 #[cfg(target_os = "windows")]
 pub fn format_sid(sid: &[u64], abbr: bool) -> String {
     let mut ret = format!("S-{}-{}-{}", sid[0], sid[1], sid[2]);
@@ -294,9 +287,9 @@ pub fn format_sid(sid: &[u64], abbr: bool) -> String {
 }
 
 pub fn bytify(x: u64) -> String {
-    let byte = Byte::from_bytes(x as u128);
-    let byte = byte.get_appropriate_unit(true);
-    byte.format(3).replace([' ', 'B', 'i'], "")
+    let byte = Byte::from_u64(x);
+    let byte = byte.get_appropriate_unit(UnitType::Binary);
+    format!("{:.3}", byte).replace([' ', 'B', 'i'], "")
 }
 
 pub fn lap(instant: &mut Instant, msg: &str) {
@@ -365,3 +358,16 @@ pub fn ptr_to_cstr(
     let x = unsafe { std::slice::from_raw_parts::<u8>(ptr, len) };
     std::ffi::CStr::from_bytes_until_nul(x)
 }
+
+#[cfg(any(target_os = "linux", target_os = "android"))]
+pub fn process_new(
+    pid: i32,
+    procfs: &Option<std::path::PathBuf>,
+) -> procfs::ProcResult<procfs::process::Process> {
+    if let Some(ref x) = procfs {
+        let path = x.join(pid.to_string());
+        procfs::process::Process::new_with_root(path)
+    } else {
+        procfs::process::Process::new(pid)
+    }
+}
